package com.yiqi.core.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.core.domain.GoodsStore;
import com.yiqi.system.domain.ManageFactory;
import com.yiqi.system.domain.SysStore;

import java.util.List;

/**
 * 商品门店Service接口
 *
 * @author ruoyi
 * @date 2023-08-21
 */
public interface IGoodsStoreService extends IService<GoodsStore> {
    /**
     * 查询商品门店
     *
     * @param id 商品门店主键
     * @return 商品门店
     */
    public GoodsStore selectGoodsStoreById(Long id);

    /**
     * 查询商品门店列表
     *
     * @param goodsStore 商品门店
     * @return 商品门店集合
     */
    public List<GoodsStore> selectGoodsStoreList(GoodsStore goodsStore);

    /**
     * 新增商品门店
     *
     * @param goodsStore 商品门店
     * @return 结果
     */
    public int insertGoodsStore(GoodsStore goodsStore);

    /**
     * 修改商品门店
     *
     * @param goodsStore 商品门店
     * @return 结果
     */
    public int updateGoodsStore(GoodsStore goodsStore);

    /**
     * 批量删除商品门店
     *
     * @param ids 需要删除的商品门店主键集合
     * @return 结果
     */
    public int deleteGoodsStoreByIds(Long[] ids);

    /**
     * 删除商品门店信息
     *
     * @param id 商品门店主键
     * @return 结果
     */
    public int deleteGoodsStoreById(Long id);


    /**
     * 修改商品门店状态
     *
     * @param goodsStore 商品门店
     * @return 结果
     */
    public int updateGoodsStoreStatus(GoodsStore goodsStore);


    /**
     * 批量新增商品工厂关系
     *
     * @param goodsStore 商品门店
     * @return 结果
     */
    public int insertGoodsToAllFactory(GoodsStore goodsStore);

    /**
     * 批量新增商品门店关系
     *
     * @param goodsStore 商品门店
     * @return 结果
     */
    public int insertGoodsToAllStore(GoodsStore goodsStore);

    /**
     * 批量新增工厂和全部商品关系
     *
     * @param manageFactory 工厂实例
     * @return 结果
     */
    public int insertFactoryToAllGoods(ManageFactory manageFactory);

    /**
     * 批量新增门店和全部商品关系
     *
     * @param sysStore 门店实例
     * @return 结果
     */
    public int insertStoreToAllGoods(SysStore sysStore);
}
